@@ -1,13 +1,12 @@
 #
 # Net::Gadu 
 # 
-# Copyright (C) 2002-2007 Marcin Krzyanowski
+# Copyright (C) 2002-2008 Marcin Krzyżanowski
 # http://www.hakore.com
 # 
 # This program is free software; you can redistribute it and/or modify 
 # it under the terms of the GNU Lesser General Public License as published by 
-# the Free Software Foundation; either version 2 of the License, or 
-# (at your option) any later version. 
+# the Free Software Foundation; either version 2 of the License 
 # 
 # This program is distributed in the hope that it will be useful, 
 # but WITHOUT ANY WARRANTY; without even the implied warranty of 
@@ -38,22 +37,25 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '1.8';
+our $VERSION = '1.9';
 
 
 our $EVENT_NONE = 0;
 our $EVENT_MSG = 1;
 our $EVENT_NOTIFY = 2;
-our $EVENT_NOTIFY60 = 23;
 our $EVENT_NOTIFY_DESCR = 3;
 our $EVENT_STATUS = 4;
-our $EVENT_STATUS60 = 22;
 our $EVENT_ACK = 5;
 our $EVENT_PONG = 6; 
 our $EVENT_CONN_FAILED = 7;
 our $EVENT_CONN_SUCCESS = 8;
 our $EVENT_DISCONNECT = 9;
 our $EVENT_SEARCH_REPLY = 19;
+our $EVENT_STATUS60 = 22;
+our $EVENT_NOTIFY60 = 23;
+our $EVENT_USERLIST = 24;
+our $EVENT_XML_EVENT = 35;
+our $EVENT_WELCOME = 0x0001;
 
 our $STATUS_NOT_AVAIL = 0x0001;	
 our $STATUS_NOT_AVAIL_DESCR = 0x0015;
@@ -63,6 +65,9 @@ our $STATUS_BUSY = 0x0003;
 our $STATUS_BUSY_DESCR = 0x0005;
 our $STATUS_INVISIBLE = 0x0014;
 our $STATUS_INVISIBLE_DESCR = 0x0016;
+our $STATUS_BLOCKED = 0x0006;
+
+our $STATUS_FRIENDS_MASK = 0x8000;
 
 bootstrap Net::Gadu $VERSION;
 
@@ -70,8 +75,12 @@ bootstrap Net::Gadu $VERSION;
 sub new {
     my ($c, %args) = @_;
     my $class = ref($c) || $c;
-    if (!exists($args{server})) { $args{server} = "217.17.41.88"; }
-    if (!exists($args{async})) { $args{async} = 1; }
+    if (!exists($args{async})) { 
+	$args{async} = 1; 
+    }
+    if (!exists($args{server})) { 
+	$args{server} = "0.0.0.0"; #appmsg.gadu-gadu.pl
+    }
     bless \%args, $class;
 }
 
@@ -87,10 +96,10 @@ sub search {
 }
 
 sub login {
-    my ($cl,$uin,$password) = @_;
-    $cl->{uin}=$uin;
-    $cl->{password}=$password;
-    $cl->{session} = Net::Gadu::gg_login($cl->{uin},$cl->{password},$cl->{async},$cl->{server});
+    my ($cl,$uin,$password,$initial_status) = @_;
+    $cl->{uin} = $uin;
+    $cl->{password} = $password;
+    $cl->{session} = Net::Gadu::gg_login($cl->{uin},$cl->{password},$cl->{async}, $cl->{server}, $initial_status ? $initial_status : $STATUS_AVAIL);
     return $cl->{session};
 }
 
@@ -136,17 +145,17 @@ sub change_status_descr {
 }
 
 sub set_available {
-    my ($cl,$status) = @_;
+    my ($cl) = @_;
     $cl->change_status($Net::Gadu::STATUS_AVAIL); # GG_STATUS_AVAIL
 }
 
 sub set_busy {
-    my ($cl,$status) = @_;
+    my ($cl) = @_;
     $cl->change_status($Net::Gadu::STATUS_BUSY); # GG_STATUS_BUSY
 }
 
 sub set_not_available {
-    my ($cl,$status) = @_;
+    my ($cl) = @_;
     $cl->change_status($Net::Gadu::STATUS_NOT_AVAIL); # GG_STATUS_NOT_AVAIL
 }
 
@@ -155,6 +164,11 @@ sub set_invisible {
     $cl->change_status($Net::Gadu::STATUS_INVISIBLE); # GG_STATUS_INVISIBLE
 }
 
+sub notify {
+    my ($cl) = @_;
+    return Net::Gadu::gg_notify($cl->{session});
+}
+
 sub add_notify {
     my ($cl,$uin) = @_;
     return Net::Gadu::gg_add_notify($cl->{session},$uin);
@@ -173,23 +187,24 @@ __END__
 
 =head1 NAME
 
-Net::Gadu - Interfejs do biblioteki libgadu.so dla protokou Gadu-Gadu 
+Net::Gadu - Interfejs do biblioteki libgadu.so dla protokołu komunikatora Gadu-Gadu 
 
 =head1 DESCRIPTION
 
-Wykorzystuje biblioteke libgadu.so ktora jest czescia projektu EKG.
-Aby zaintalowac libgadu.so nalezy skompilowac EKG z opcja --with-shared. Jesli uzywasz EKG z pakietu prawdopodobnie
-biblioteka ta zostala zainstalowana. Szczegolowe informacje znajdziesz na stronie projektu EKG - http://ekg.chmurka.net/
-Do zbudowania pakietu potrzeba jest zainstalowana biblioteka z prefixem /usr lub /usr/local , jesli lokalizacja jest niestandardowa mozna wyedytowac plik Makefile.PL podajac wlasciwe lokalizacje
+Wykorzystuje bibliotekę libgadu.so która jest częścią projektu EKG.
+Szczegółowe informacje na temat instalacji biblioteki Libgadu znajdziesz na stronie projektu EKG - http://ekg.chmurka.net/
+.Do zbudowania pakietu Net::Gadu potrzebna jest zainstalowana w systemie biblioteka Libgadu.
+
+     Jeżeli biblioteka Libgadu została zainstalowana w niestandardowym miejscu w systemie należy wyedytowac plik Makefile.PL podając właściwą lokalizację.
 
 =head1 DOWNLOAD
 
-http://www.cpan.org/modules/by-module/Net/Net-Gadu-1.8.tar.gz
+http://www.cpan.org/modules/by-module/Net/Net-Gadu-1.9.tar.gz
 
 
 =head1 SUBVERSION
 
-$ svn co http://svn.hakore.com/netgadu/trunk
+$ svn co http://svn.hakore.com/netgadu/
 
 
 =head1 METHODS
@@ -201,28 +216,33 @@ Dostepne metody :
 =item $gg = new Net::Gadu()
 
     opcjonalny parametr :
-    server => "11.11.11.11"  (ip alternatywnego serwera)
     async => 1 lub 0   (komunikacja asynchroniczna lub nie)
+    server => "91.197.13.211"  (alternatywne IP serwera Gadu-Gadu. Nie ustawiaj jezeli nie wiesz co to oznacza)
 
 
-=item $gg->login(uin, password);
+=item $gg->login($uin, $password, $initial_status);
 
-Polaczenie z serwerem oraz logowanie do serwera.
+Polaczenie z serwerem oraz logowanie do serwera. Pamietaj aby zaraz po polaczeniu wykonac $gg->notify();
+
+    parametry:
+    $uin = numer Gadu-Gadu
+    $password = haslo
+    $initial_status = status ustawiany po polaczeniu (opcjonalny)
 
 
 =item $gg->logoff();
 
-Wylogowanie z serwera i zakonczenie sesji.
+Wylogowanie z serwera i zakończenie sesji.
 
 
-=item $gg->send_message(receiver_uin, message);
+=item $gg->send_message($receiver_uin, $message);
 
-Wysyla wiadomosc pod wskazany numer UIN.
+Wysyła wiadomość pod wskazany numer UIN.
 
 
-=item $gg->send_message_chat(receiver_uin, message);
+=item $gg->send_message_chat($receiver_uin, $message);
 
-Wysyla wiadomosc pod wskazany numer UIN.
+Wysyła wiadomość pod wskazany numer UIN.
 
 
 =item $gg->set_available();
@@ -230,20 +250,24 @@ Wysyla wiadomosc pod wskazany numer UIN.
 Ustawia status na dostepny. Podobne funkcje : set_busy(), set_invisible(), set_not_available(), change_status().
 
 
-=item $gg->add_notify()
+=item $gg->add_notify($uin)
 
-Możesz użyc tej funkcji w celu poinformowania serwera, że chcesz znać status danej osoby i czekać na zdarzenia zwiazane ze zmiana statusu.
-Zaczynaja dochodzic zdarzenia EVENT_NOTIFY,EVENT_NOTIFY60 gdy ktos sie pojawi oraz EVENT_STATUS,EVENT_STATUS60 gdy ktos zmieni status (patrz opis get_event())
+    parametry:
+    $uin = numer Gadu-Gady który chcemy obserwować.
+
+Możesz użyć tej funkcji w celu poinformowania serwera, że chcesz znać status danej osoby i otrzymywać zdarzenia zwiazane ze zmianą statusu. Od tego momentu zaczynają nadchodzić z serwera zdarzenia EVENT_NOTIFY, EVENT_NOTIFY60 zawsze gdy ktoś się pojawi oraz EVENT_STATUS,EVENT_STATUS60 gdy ktoś zmieni status (patrz opis get_event())
 
 
-=item $gg->remove_notify()
+=item $gg->remove_notify($uin)
 
-Możesz użyc tej funkcji w celu poinformowania serwera, że nie chcesz otrzymywac zdarzen zwiazanych ze zmiana statusu od tej osoby.
+Możesz użyć tej funkcji w celu poinformowania serwera, że nie chcesz otrzymywać zdarzeń związanych ze zmianą statusu od tej osoby.
 
+    parametry:
+    $uin = numer Gadu-Gadu
 
-=item $gg->change_status();
+=item $gg->change_status($status);
 
-Zmiana statusu mozliwa na jeden z:
+Zmiana statusu możliwa jest na jeden z:
 
     $Net::Gadu::STATUS_NOT_AVAIL
     $Net::Gadu::STATUS_AVAIL
@@ -251,9 +275,13 @@ Zmiana statusu mozliwa na jeden z:
     $Net::Gadu::STATUS_INVISIBLE
 
 
-=item $gg->change_status_descr();
+=item $gg->change_status_descr($status, $descr);
 
-Zmiana statusu z opisem, mozliwa na jeden z:
+    parametry:
+    $status = nowy status
+    $descr  = tekst opisu
+
+Zmiana statusu z opisem możliwa na jeden z:
 
     $Net::Gadu::STATUS_NOT_AVAIL_DESCR
     $Net::Gadu::STATUS_AVAIL_DESCR
@@ -263,12 +291,11 @@ Zmiana statusu z opisem, mozliwa na jeden z:
 
 =item $gg->search($uin,$nickname,$first_name,$last_name,$city,$gender,$active)
 
-    Wyszukiwanie, jesli parametr ma warto "", czyli pust wtedy to pole nie
-    jest brane pod uwag podczas wyszukiwania.
-    Zwracana jest tablica ze szczegoowymi informacjami.
-    Odpowied naley odebra po otrzymaniu zdarzenia $Net::Gadu::EVENT_SEARCH_REPLY.
-    Przykadowe uycie oraz wynik znajduj si w przykadowym
-    programie "ex/ex1" dostarczanym wraz ze rdami.
+Wyszukiwanie, jesli parametr ma wartość "", czyli pustą wtedy to pole nie jest brane pod uwagę podczas wyszukiwania.
+Zwracana jest tablica ze szczegołowymi informacjami.
+
+Odpowiedź należy odebrać po otrzymaniu zdarzenia $Net::Gadu::EVENT_SEARCH_REPLY.
+Przykładowe użycie oraz wynik znajdują się w przykładowym programie "ex/ex1" dostarczanym wraz ze źródłami.
 
     Uwaga:
     $gender = "male" lub "female" lub "none")
@@ -339,6 +366,8 @@ Zmiana statusu z opisem, mozliwa na jeden z:
     $Net::Gadu::EVENT_CONN_SUCCESS 
     $Net::Gadu::EVENT_DISCONNECT
     $Net::Gadu::EVENT_SEARCH_REPLY
+    $Net::Gadu::$EVENT_XML_EVENT
+    $Net::Gadu::$EVENT_WELCOME
 
 
 =back
@@ -347,67 +376,69 @@ Zmiana statusu z opisem, mozliwa na jeden z:
 
 =over 4
 
-#!/usr/bin/perl
+    #!/usr/bin/perl
 
-use Net::Gadu; 
-use Data::Dumper;
+    use Net::Gadu; 
+    use Data::Dumper;
 
-my $gg = new Net::Gadu(async=>1);
+    my $gg = new Net::Gadu(async => 1);
 
-## LOGIN
-$gg->login("1234567","password") or die "Login error\n";
+    $gg->login("1234567", "password", $Net::Gadu::STATUS_BUSY) or die "Login error\n";
 
-## EVENTS(this example, after successful login change status, send message and logout
-while (1) {
-    while ($gg->check_event() == 1) {
+    #main loop. In this example, after successful login change status, send message and logout
+    while (1) {
+    
+	while ($gg->check_event() == 1) {
 
-	my $e = $gg->get_event();
-
-	my $type = $e->{type};
+	    my $e = $gg->get_event();
+	    my $type = $e->{type};
 	
-	if ($type == $Net::Gadu::EVENT_CONN_FAILED) {
-	    die "Connection failed";
-	}
+    	    if ($type == $Net::Gadu::EVENT_CONN_FAILED) {
+		die "Connection failed";
+	    }
 
-	if ($type == $Net::Gadu::EVENT_NOTIFY60) {
-	    print "EVENT_NOTIFY60 from ".$e->{uin}."\n" ;
-	}
+	    if ($type == $Net::Gadu::EVENT_NOTIFY60) {
+		print "EVENT_NOTIFY60 from ".$e->{uin}."\n" ;
+	    }
 
-	if ($type == $Net::Gadu::EVENT_STATUS60) {
-	    print "EVENT_STATUS60 from ".$e->{uin}.", status ".$e->{status}."\n" ;
-	}
+	    if ($type == $Net::Gadu::EVENT_STATUS60) {
+		print "EVENT_STATUS60 from ".$e->{uin}.", status ".$e->{status}."\n" ;
+	    }
 
-	if ($type == $Net::Gadu::EVENT_DISCONNECT) {
-	    die "disconnect";
-	}
+	    if ($type == $Net::Gadu::EVENT_DISCONNECT) {
+		die "disconnect";
+	    }
 	
-	if ($type == $Net::Gadu::EVENT_CONN_SUCCESS) {
-	    $gg->set_available();
-
-	    # notify server that you want to receive status notifications
-	    $gg->add_notify("42112");
-
-	    # Send THANKS to author
-	    $gg->send_message_chat("42112","dziekuje za Net::Gadu");
-
+	    if ($type == $Net::Gadu::EVENT_CONN_SUCCESS) {
+		print "CONNECTED\n";
 	    
-	    # SEARCH INIT
-	    $gg->search("","krzak","","","","male",0);
-	}
+		#it have to be sent after connect success
+		$gg->notify();
 
-	if ($type == $Net::Gadu::EVENT_MSG) {
-	    print $e->{message}." ".$e->{sender}."\n";
-	}
+		# notify server that you want to receive status notifications
+		$gg->add_notify("42112");
 
-	if ($type == $Net::Gadu::EVENT_SEARCH_REPLY) {
-	    # SEARCH RESULT
-	    print Dumper($e->{results});
-	    #$gg->logoff();
-	    #exit(1);
-	}
+		# Send THANKS to author
+		$gg->send_message_chat("42112","dziekuje za Net::Gadu");
+	    
+		# SEARCH INIT
+		$gg->search("","krzak","","","","male",0);
+	    }
 
-	if ($type == $Net::Gadu::EVENT_ACK) {
-	}
+	    if ($type == $Net::Gadu::EVENT_MSG) {
+		print $e->{message}." ".$e->{sender}."\n";
+	    }
+
+	    if ($type == $Net::Gadu::EVENT_SEARCH_REPLY) {
+		# SEARCH RESULT
+		print Dumper($e->{results});
+		#$gg->logoff();
+		#exit(1);
+	    }
+
+	    if ($type == $Net::Gadu::EVENT_ACK) {
+		print "EVENT_ACK\n";
+	    }
     }
 }
 
@@ -415,11 +446,11 @@ while (1) {
 
 =head1 AUTHOR
 
-Marcin Krzyanowski, http://www.hakore.com/
+Marcin Krzyżanowski, http://www.hakore.com/
 
 =head1 LICENCE
 
-Lesser General Public License
+Lesser General Public License v. 2
 
 =head1 SEE ALSO
 
